*******
WULFRIC
*******
Crystal, Lattice, Atoms, K-path.

.. image:: https://badge.fury.io/py/wulfric.svg
  :target: https://badge.fury.io/py/wulfric/

.. image:: https://readthedocs.org/projects/wulfric/badge/?version=latest
    :target: https://wulfric.org/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
  :target: https://github.com/psf/black/

.. image:: https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=505050
  :target: https://pycqa.github.io/isort/

.. image:: https://img.shields.io/badge/License-GPLv3-blue.svg
  :target: https://www.gnu.org/licenses/gpl-3.0


For the detailed description check
`documentation. <https://wulfric.org>`_

Installation
============

Requirement for WULFRIC installation are:

* Python (>=3.8)
* NumPy
* SciPy
* termcolor
* matplotlib (optional)
* plotly (optional)

Optional dependencies are required if you want to use visual capabilities.

WULFRIC can be installed with ``pip`` or from source.

pip
---

To install WULFRIC, run (you may need to use ``pip3``):

.. code-block:: console

  pip install wulfric

To install with optional visualisation capabilities, run (you may need to use ``pip3``):

.. code-block:: console

  pip install wulfric[visual]

Installing from source
----------------------

* Clone the project to your local computer:

.. code-block:: console

  git clone git@github.com:adrybakov/wulfric.git

* Change the directory:

.. code-block:: console

  cd wulfric

* Instal the dependencies (you may need to use ``pip3``):

.. code-block:: console

  pip install -r requirements.txt

* To install WULFRIC, run (you may need to use ``pip3``):

.. code-block:: console

  pip install wulfric
